@@ -1,12 +1,11 @@
-import argparse
+# import argparse
 import pytest
 import tempfile
 from unittest import mock
 from .. import submission as submission_module
 from ..submission import DEFAULT_INGESTION_TYPE
 from ..scripts.submit_metadata_bundle import (
-    main as submit_metadata_bundle_main,
-    _setup_validate_related_options
+    main as submit_metadata_bundle_main
 )
 from ..scripts import submit_metadata_bundle as submit_metadata_bundle_module
 from .testing_helpers import system_exit_expected, argparse_errors_muffled
@@ -59,13 +58,13 @@ def test_submit_metadata_bundle_script(keyfile):
         'subfolders': False,
     }
     test_it(args_in=["--env", "some-env",  # "--institution", "some-institution",
-                     "-s", "some-server", "-v",  # "-p", "some-project",
+                     "--server", "some-server", "--validate",  # "-p", "some-project",
                      some_file],
             expect_exit_code=0,
             expect_called=True,
             expect_call_args=expect_call_args)
     test_it(args_in=[some_file, "--env", "some-env",  # "--institution", "some-institution",
-                     "-s", "some-server", "--validate-only"],  # , "--project", "some-project"],
+                     "--server", "some-server"],  # , "--project", "some-project"],
             expect_exit_code=0,
             expect_called=True,
             expect_call_args=expect_call_args)
@@ -83,9 +82,9 @@ def test_submit_metadata_bundle_script(keyfile):
     }
     test_it(args_in=["--env", "some-env",
                      # "--institution", "some-institution",
-                     "-s", "some-server",
+                     "--server", "some-server",
                      # "-p", "some-project",
-                     '-u', 'a-folder',
+                     '--directory', 'a-folder',
                      some_file],
             expect_exit_code=0,
             expect_called=True,
@@ -93,9 +92,9 @@ def test_submit_metadata_bundle_script(keyfile):
     test_it(args_in=[some_file,
                      "--env", "some-env",
                      # "--institution", "some-institution",
-                     "-s", "some-server",
+                     "--server", "some-server",
                      # "--project", "some-project",
-                     '--upload_folder', 'a-folder'],
+                     '--directory', 'a-folder'],
             expect_exit_code=0,
             expect_called=True,
             expect_call_args=expect_call_args)
@@ -113,11 +112,11 @@ def test_submit_metadata_bundle_script(keyfile):
     }
     test_it(args_in=["--env", "some-env",
                      # "--institution", "some-institution",
-                     "-s", "some-server",
-                     "-v",
+                     "--server", "some-server",
+                     "--validate",
                      # "-p", "some-project",
-                     '-u', 'a-folder',
-                     '-t', 'simulated_bundle',
+                     '--directory', 'a-folder',
+                     '--ingestion_type', 'simulated_bundle',
                      some_file],
             expect_exit_code=0,
             expect_called=True,
@@ -125,10 +124,9 @@ def test_submit_metadata_bundle_script(keyfile):
     test_it(args_in=[some_file,
                      "--env", "some-env",
                      # "--institution", "some-institution",
-                     "-s", "some-server",
-                     "--validate-only",
+                     "--server", "some-server",
                      # "--project", "some-project",
-                     '--upload_folder', 'a-folder',
+                     '--directory', 'a-folder',
                      '--ingestion_type', 'simulated_bundle'],
             expect_exit_code=0,
             expect_called=True,
@@ -146,14 +144,14 @@ def test_submit_metadata_bundle_script(keyfile):
         'subfolders': True,
     }
     test_it(args_in=["--env", "some-env",  # "--institution", "some-institution",
-                     "-s", "some-server", "-v",  # "-p", "some-project",
-                     some_file, '-nq', '-sf'],
+                     "--server", "some-server", "--validate",  # "-p", "some-project",
+                     some_file, '--yes'],
             expect_exit_code=0,
             expect_called=True,
             expect_call_args=expect_call_args)
     test_it(args_in=["--env", "some-env",  # "--institution", "some-institution",
-                     "-s", "some-server", "-v",  # "-p", "some-project",
-                     some_file, '--no_query', '--subfolders'],
+                     "--server", "some-server", "--validate",  # "-p", "some-project",
+                     some_file, '--yes'],
             expect_exit_code=0,
             expect_called=True,
             expect_call_args=expect_call_args)
@@ -166,63 +164,3 @@ def _create_some_temporary_file() -> str:
     finally:
         some_file.close()
     return some_file.name
-
-
-def test_validation_options():
-
-    args = argparse.Namespace(submit=False,
-                              validate=False,
-                              validate_only=False,
-                              validate_remote=False,
-                              validate_remote_only=False,
-                              validate_local=False,
-                              validate_local_only=False)
-    _setup_validate_related_options(args)
-    # Note This is for admin users; for non-admin users it would be (TODO):
-    # assert (not args.validate_local and
-    #         not args.validate_local_only and
-    #         not args.validate_remote and
-    #         not args.validate_remote_only)
-    assert (not args.validate_local and
-            not args.validate_local_only and
-            not args.validate_remote and
-            not args.validate_remote_only)
-
-    args = argparse.Namespace(submit=False,
-                              validate=True,
-                              validate_only=False,
-                              validate_remote=False,
-                              validate_remote_only=False,
-                              validate_local=False,
-                              validate_local_only=False)
-    _setup_validate_related_options(args)
-    assert (args.validate_local and
-            not args.validate_local_only and
-            args.validate_remote and
-            args.validate_remote_only)
-
-    args = argparse.Namespace(submit=False,
-                              validate=False,
-                              validate_only=True,
-                              validate_remote=False,
-                              validate_remote_only=False,
-                              validate_local=False,
-                              validate_local_only=False)
-    _setup_validate_related_options(args)
-    assert (args.validate_local and
-            not args.validate_local_only and
-            not args.validate_remote and
-            args.validate_remote_only)
-
-    args = argparse.Namespace(submit=False,
-                              validate=False,
-                              validate_only=False,
-                              validate_remote=False,
-                              validate_remote_only=False,
-                              validate_local=True,
-                              validate_local_only=False)
-    _setup_validate_related_options(args)
-    assert (args.validate_local and
-            not args.validate_local_only and
-            not args.validate_remote and
-            not args.validate_remote_only)
